@@ -40,8 +40,9 @@ OrderedDict <- function(items = NULL) {
 
     initialize <- function(items = NULL) {
         clear()
-        for (argname in names(items)) {
-            set(argname, items[[argname]])
+        keys <- names(items)
+        for (i in seq_along(items)) {
+            set(keys[i], items[[i]])
         }
     }
     set <- function(key, value) {
@@ -165,8 +166,9 @@ OrderedDictL <- function(items = NULL) {
 
     initialize <- function(items = NULL) {
         clear()
-        for (argname in names(items)) {
-            set(argname, items[[argname]])
+        keys <- names(items)
+        for (i in seq_along(items)) {
+            set(keys[i], items[[i]])
         }
     }
     set <- function(key, value) {
