@@ -24,8 +24,8 @@ static const R_CallMethodDef CallEntries[] = {
     {"deque_popleft", (DL_FUNC) &deque_popleft, 1},
     {"deque_remove", (DL_FUNC) &deque_remove, 2},
     {"dict_index_get", (DL_FUNC) &dict_index_get, 3},
-    {"dict_index_set", (DL_FUNC) &dict_index_set, 4},
-    {"dict_index_remove", (DL_FUNC) &dict_index_remove, 3},
+    {"dict_set", (DL_FUNC) &dict_set, 4},
+    {"dict_remove", (DL_FUNC) &dict_remove, 3},
     {"heapify", (DL_FUNC) &heapify, 1},
     {"heap_push", (DL_FUNC) &heap_push, 3},
     {"heap_pop", (DL_FUNC) &heap_pop, 1},
